==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/mixin/VanillaResourcePackProviderMixin.java <==
package com.zurrtum.create.mixin;

import com.zurrtum.create.foundation.pack.DynamicPack;
import com.zurrtum.create.foundation.pack.RuntimeDataGenerator;
import net.fabricmc.loader.api.FabricLoader;
import net.fabricmc.loader.api.ModContainer;
import net.fabricmc.loader.api.metadata.ModMetadata;
import net.minecraft.class_155;
import net.minecraft.class_2561;
import net.minecraft.class_3262;
import net.minecraft.class_3264;
import net.minecraft.class_3272;
import net.minecraft.class_3286;
import net.minecraft.class_3288;
import net.minecraft.class_5352;
import net.minecraft.class_7662;
import net.minecraft.class_7665;
import net.minecraft.class_7678;
import net.minecraft.class_9224;
import net.minecraft.class_9225;
import net.minecraft.class_9226;
import net.minecraft.resource.*;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.nio.file.Path;
import java.util.List;
import java.util.Optional;
import java.util.function.Consumer;

import static com.zurrtum.create.Create.MOD_ID;

@Mixin(class_7678.class)
public class VanillaResourcePackProviderMixin {
    @Inject(method = "register(Ljava/util/function/Consumer;)V", at = @At("TAIL"))
    private void addDataPack(Consumer<class_3288> consumer, CallbackInfo ci) {
        if ((Object) this instanceof class_3286) {
            FabricLoader loader = FabricLoader.getInstance();
            if (!loader.isModLoaded("fabric-api")) {
                String directory = class_3264.field_14190.method_14413();
                ModContainer mod = loader.getModContainer(MOD_ID).orElseThrow();
                List<Path> paths = mod.getRootPaths();
                addDataPack(
                    consumer,
                    createInfo("fabric-convention-tags-v2", "Fabric Convention Tags (v2)", "2.15.2+d9a8963096"),
                    paths,
                    class_2561.method_30163("fabric-convention-tags-v2-2.15.2+d9a8963096"),
                    directory + "/fabric",
                    "c"
                );
                ModMetadata metadata = mod.getMetadata();
                addDataPack(
                    consumer,
                    createInfo(MOD_ID, metadata.getName(), metadata.getVersion().getFriendlyString()),
                    paths,
                    class_2561.method_43471("advancement.create.root"),
                    directory,
                    MOD_ID,
                    "minecraft",
                    "c"
                );
            }
            DynamicPack dynamicPack = new DynamicPack("create:dynamic_data", class_2561.method_43471("advancement.create.root"), class_3264.field_14190);
            RuntimeDataGenerator.insertIntoPack(dynamicPack);
            if (!dynamicPack.isEmpty()) {
                addDataPack(consumer, false, dynamicPack);
            }
        }
    }

    @Unique
    private static class_9224 createInfo(String id, String name, String version) {
        return new class_9224(id, class_2561.method_30163(name), class_5352.field_25348, Optional.of(new class_9226(id, "data", version)));
    }

    @Unique
    private static void addDataPack(
        Consumer<class_3288> consumer,
        class_9224 info,
        List<Path> paths,
        class_2561 title,
        String directory,
        String... namespace
    ) {
        class_7662 metadataMap = class_7662.method_45174(
            class_3272.field_14202,
            new class_3272(title, class_155.method_16673().method_70592(class_3264.field_14190), Optional.empty())
        );
        class_7665 builder = new class_7665().method_45198(metadataMap).method_45206(namespace);
        for (Path path : paths) {
            builder.method_45201(class_3264.field_14190, path.resolve(directory));
        }
        addDataPack(consumer, true, builder.method_45210(info));
    }

    @Unique
    private static void addDataPack(Consumer<class_3288> consumer, boolean required, class_3262 pack) {
        class_3288.class_7680 packFactory = new class_3288.class_7680() {
            @Override
            public class_3262 method_52424(class_9224 info) {
                return pack;
            }

            @Override
            public class_3262 method_52425(class_9224 info, class_3288.class_7679 metadata) {
                return pack;
            }
        };
        class_9225 position = new class_9225(required, class_3288.class_3289.field_14281, false);
        consumer.accept(class_3288.method_45275(pack.method_56926(), packFactory, class_3264.field_14190, position));
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/mixin/VanillaResourcePackProviderMixin.java <==
package com.zurrtum.create.mixin;

import com.zurrtum.create.foundation.pack.DynamicPack;
import com.zurrtum.create.foundation.pack.RuntimeDataGenerator;
import net.fabricmc.loader.api.FabricLoader;
import net.fabricmc.loader.api.ModContainer;
import net.fabricmc.loader.api.metadata.ModMetadata;
import net.minecraft.class_155;
import net.minecraft.class_2561;
import net.minecraft.class_3262;
import net.minecraft.class_3264;
import net.minecraft.class_3272;
import net.minecraft.class_3286;
import net.minecraft.class_3288;
import net.minecraft.class_5352;
import net.minecraft.class_7662;
import net.minecraft.class_7665;
import net.minecraft.class_7678;
import net.minecraft.class_9224;
import net.minecraft.class_9225;
import net.minecraft.class_9226;
import net.minecraft.resource.*;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.nio.file.Path;
import java.util.List;
import java.util.Optional;
import java.util.function.Consumer;

import static com.zurrtum.create.Create.MOD_ID;

@Mixin(class_7678.class)
public class VanillaResourcePackProviderMixin {
    @Inject(method = "register(Ljava/util/function/Consumer;)V", at = @At("TAIL"))
    private void addDataPack(Consumer<class_3288> consumer, CallbackInfo ci) {
        if ((Object) this instanceof class_3286) {
            FabricLoader loader = FabricLoader.getInstance();
            if (!loader.isModLoaded("fabric-api")) {
                String directory = class_3264.field_14190.method_14413();
                ModContainer mod = loader.getModContainer(MOD_ID).orElseThrow();
                List<Path> paths = mod.getRootPaths();
                addDataPack(
                    consumer,
                    createInfo("fabric-convention-tags-v2", "Fabric Convention Tags (v2)", "2.15.2+d9a8963096"),
                    paths,
                    class_2561.method_30163("fabric-convention-tags-v2-2.15.2+d9a8963096"),
                    directory + "/fabric",
                    "c"
                );
                ModMetadata metadata = mod.getMetadata();
                addDataPack(
                    consumer,
                    createInfo(MOD_ID, metadata.getName(), metadata.getVersion().getFriendlyString()),
                    paths,
                    class_2561.method_43471("advancement.create.root"),
                    directory,
                    MOD_ID,
                    "minecraft",
                    "c"
                );
            }
            DynamicPack dynamicPack = new DynamicPack("create:dynamic_data", class_2561.method_43471("advancement.create.root"), class_3264.field_14190);
            RuntimeDataGenerator.insertIntoPack(dynamicPack);
            if (!dynamicPack.isEmpty()) {
                addDataPack(consumer, false, dynamicPack);
            }
        }
    }

    @Unique
    private static class_9224 createInfo(String id, String name, String version) {
        return new class_9224(id, class_2561.method_30163(name), class_5352.field_25348, Optional.of(new class_9226(id, "data", version)));
    }

    @Unique
    private static void addDataPack(
        Consumer<class_3288> consumer,
        class_9224 info,
        List<Path> paths,
        class_2561 title,
        String directory,
        String... namespace
    ) {
        class_7662 metadataMap = class_7662.method_45174(
            class_3272.field_61156,
            new class_3272(title, class_155.method_16673().method_70592(class_3264.field_14190).method_72318())
        );
        class_7665 builder = new class_7665().method_45198(metadataMap).method_45206(namespace);
        for (Path path : paths) {
            builder.method_45201(class_3264.field_14190, path.resolve(directory));
        }
        addDataPack(consumer, true, builder.method_45210(info));
    }

    @Unique
    private static void addDataPack(Consumer<class_3288> consumer, boolean required, class_3262 pack) {
        class_3288.class_7680 packFactory = new class_3288.class_7680() {
            @Override
            public class_3262 method_52424(class_9224 info) {
                return pack;
            }

            @Override
            public class_3262 method_52425(class_9224 info, class_3288.class_7679 metadata) {
                return pack;
            }
        };
        class_9225 position = new class_9225(required, class_3288.class_3289.field_14281, false);
        consumer.accept(class_3288.method_45275(pack.method_56926(), packFactory, class_3264.field_14190, position));
    }
}
